@@ -8,6 +8,10 @@ extern "C" {
     pub fn rb_define_class_under(outer: Value, name: *const c_char, superclass: Value) -> Value;
     pub fn rb_define_method(klass: Value, name: *const c_char, callback: CallbackPtr, argc: Argc);
     pub fn rb_define_module(name: *const c_char) -> Value;
+    pub fn rb_define_module_under(outer: Value, name: *const c_char) -> Value;
+    pub fn rb_include_module(klass: Value, module: Value);
+    pub fn rb_extend_object(object: Value, module: Value);
+    pub fn rb_prepend_module(klass: Value, module: Value);
     pub fn rb_ivar_get(object: Value, name: Id) -> Value;
     pub fn rb_ivar_set(object: Value, name: Id, value: Value) -> Value;
     pub fn rb_mod_ancestors(module: Value) -> Value;
