@@ -4,11 +4,13 @@ pub mod array;
 pub mod constant;
 pub mod class;
 pub mod fixnum;
-pub mod types;
+pub mod gc;
 pub mod hash;
 pub mod rproc;
 pub mod string;
 pub mod symbol;
+pub mod typed_data;
+pub mod types;
 pub mod util;
 pub mod value;
 pub mod vm;
