@@ -1,6 +1,8 @@
 use libc::{intptr_t, uintptr_t};
 
-pub use libc::{c_char, c_int, c_long, c_void};
+pub use libc::{c_char, c_int, c_long, c_void, size_t};
+
+pub use typed_data::{RbDataType, RbDataTypeFunction};
 pub use value::{Value, ValueType};
 
 pub type Id = uintptr_t;
